Welcome to FIMserv's documentation!
====================================

This framework presents a streamlined, user-friendly, and cloud-enabled pipeline 
to generate operational flood inundation maps using the NOAA Office of Water Prediction (OWP) 
Height Above Nearest Drainage (HAND) Flood Inundation Mapping (FIM) framework. 
It is developed under the Surface Dynamics Modeling Lab (SDML) as part of a project funded 
by the Cooperative Institute for Research to Operations in Hydrology (CIROH).

.. image:: _static/graphicaloverview.png
   :alt: Project Logo
   :align: center
   :width: 1000px

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   installation
   FIMin3Steps
   detailedusage
